<?php namespace RWMedia\Analyze;

function url($inputUrl = '', $id = null) {
	$output = [];
	
	$id = $id ?? \RWMedia\Crypto::rwHash($inputUrl);
	
	$analyzeExtensionArr = [
		[
			'type' => 'youtube',
			'pattern' => '/(youtu\.be)|(youtube\.com\/watch)|(youtube\.com\/embed)/i',
		],
		[
			'type' => 'vimeo',
			'pattern' => '/vimeo\.com/i',
		],
		[
			'type' => 'imgur',
			'pattern' => '/imgur.com/i',
		],
		[
			'type' => 'facebook',
			'pattern' => '/facebook.com/i',
		],
		[
			'type' => 'streamable',
			'pattern' => '/streamable.com/i',
		],
		[
			'type' => 'unknown', //unknown type, trying for any image or video
			'pattern' => '/.*?/i',
		],
	];
	
	foreach ($analyzeExtensionArr as $element) {
		
		// 'type' is identical to the corresponding function name to call.
		// We have to use fully qualified names with call_user_func() and is_callable().
		$functionReference = "\\" . __NAMESPACE__ . "\\" . $element['type'];
		
		if (preg_match($element['pattern'], $inputUrl) && is_callable($functionReference) ) {
			$output = call_user_func($functionReference, [
					'inputUrl' => $inputUrl,
					'id' => $id,
				]
			);
			
			break;
		}
	}
    
	$defaults = [
		'status' => 7, // 4=processing or uploading, 6=recognized but errors happened, 7=not recognised, 8=finished
	];
	
	$output += $defaults;
	
	return $output;
}

?>