<?php namespace RWMedia\Analyze;

function streamable($args) {
	
	[
		'inputUrl' => $inputUrl,
	] = $args;
	
	$output = [];
			
	//get ID
	preg_match('/streamable.com\/(.{6})/i', $inputUrl, $matches);
		
	if (count($matches) > 0) {
		$id = $matches[1];
		
		//we can use the streamableStatus function to gather data
		$statusArr = streamableStatus($id);
		
		$output = [
			'status' => 8, //8=finished
			'type' => 'video-streamable',
			'dataUrl' => $id,
			'videoDuration' => $statusArr['duration'],
			'backgroundUrl' => 'https:' . $statusArr['thumbnail_url'],
		];
	}
	
	return $output;
}

function streamableUpload($inputUrl) {
	
	$user = \RWMedia\settings()['credentials']['streamable']['user'];
	$pass = \RWMedia\settings()['credentials']['streamable']['pass'];
	
	$credentials = "$user:$pass";
	$credentials = base64_encode($credentials);
	
	$encodedUrl = rawurlencode($inputUrl);
	$responseArr = \RWHttp::request([
		'url' => "https://api.streamable.com/import?url=$encodedUrl", //needs to be encoded
		'customHeaders' => [
			"Authorization: Basic $credentials", //needs to be base64 encoded
		],
	]);
	
	$data = json_decode($responseArr['data']);
	$streamableId = $data->shortcode;
	
	return $streamableId;
}

function streamableStatus($streamableId) {
	
	$responseArr = \RWHttp::request([
		'url' => "https://api.streamable.com/videos/$streamableId",
	]);
	
	$responseStatusCode = $responseArr['headers']['status-code'];
	
	if ($responseStatusCode === '200') {
		
		$data = json_decode($responseArr['data']);
		
		// status 0 = Uploading
		// status 1 = Processing
		// status 2 = Ready
		// status 3 = Unavailable
		$status = $data->status;
		$percent = $data->percent;
		$thumbnail_url = $data->thumbnail_url;
		$message = $data->message;
		
		$durationSec = round($data->files->original->duration ?? 0); //in INT seconds
		
		//convert seconds to H:M:S
		$dtF = new \DateTime('@0');
		$dtT = new \DateTime("@$durationSec");
		$duration = $dtF->diff($dtT)->format('%H:%I:%S');
		
		$size = $data->files->original->size ?? 0; 
		$size = \RWHttp::getSize($size);
	}
	else {
		// status 4 = Not 200
		$status = 4;
		$message = "HTML response is not 200, but $responseStatusCode";
	}
	
	$output = [
		'status' => $status,
		'percent' => $percent,
		'thumbnail_url' => $thumbnail_url,
		'duration' => $duration,
		'size' => $size,
		'message' => $message
	];
	
	return $output;
}


?>