<?php namespace RWMedia\Analyze;

function unknown($args) {
	
	[
		'inputUrl' => $inputUrl,
		'id' => $id,
	] = $args;
	
	//check if url = raw image,
	$responseArr = \RWHttp::request([
		'url' => $inputUrl,
		'requestType' => 'HEAD',
		'referer' => 'www.rewired.hu',
	]);
	
	$output = [];
	
	if ($responseArr['headers']['status-code'] === '200') {
		
		//try if image
		$output = image([
			'headers' => $responseArr['headers'],
			'inputUrl' => $inputUrl,
			'id' => $id,
		]);
		
		//try if video
		if ($output['status'] === 7) {
			$output = video([
				'headers' => $responseArr['headers'],
				'inputUrl' => $inputUrl,
				'id' => $id,
			]);
		}
	}
	else {
		//not 200
	}
	
	return $output;
}

function video($args) {
	
	[
		'headers' => $headers,
		'inputUrl' => $inputUrl,
		'id' => $id,
	] = $args;
	
	$contentType = $headers['content-type'];
	
	$output = [];
	
	preg_match('/(^.*\.webm)|(^.*\.mp4)/i', $inputUrl, $videoMatches);
	
	if (count($videoMatches) > 0) {
		$type = 'video-raw';
		$webmUrl = $videoMatches[1];
		$mp4Url = $videoMatches[2];
		$size = \RWHttp::getSize($headers);
		$backgroundUrl = '';
		
		$output += [
			'status' => 8,
			'type' => $type,
			'size' => $size,
			// 'backgroundUrl' => $backgroundUrl, //TODO extract video background with some php module, like ffmpeg
		];
		
		if (strlen($videoMatches[1]) > 0) {
			$output += [
				'webmUrl' => $webmUrl,
			];
		}
		else if (strlen($videoMatches[2]) > 0) {
			$output += [
				'mp4Url' => $mp4Url,
			];
		}
		
	}
	else {
		$output += [
			'status' => 7,
		];
	}
	
	return $output;
}

function image($args) {
	
	[
		'headers' => $headers,
		'inputUrl' => $inputUrl,
		'id' => $id,
	] = $args;
	
	$type = '';
	
	// Header and EXIF check to figure out, if the file is an image
	$isImage = isImage($headers['content-type']);
	$exif = getExif($inputUrl);
	$isImage2 = $exif['isImage'];
	
	//isImage?
	if ($isImage && $isImage2) {
		
		$dimensions = getImageDimensions($inputUrl);
		$width = $dimensions[0];
		$height = $dimensions[1];
		$mime = $dimensions['mime'];
		$size = \RWHttp::getSize($headers);
		
		// $anonymizer = 'https://href.li/?';
		// https://href.li/?
		// https://anon.click/
		// https://www.anonymizer.info/?
		// https://referer.us/?
		// $fixed_url = $anonymizer.$orig_url;
		
		//isAnimated?
		if ($mime === 'image/gif' && isAnimated($inputUrl, $exif)) {
			$type = 'image-raw-animated';

			$dirs = \RWMedia\settings()['dirs'];
			$fileName = "$id.jpg";
			
			$fullPath = $dirs['dir_gif_thumbnails'] . $fileName;
			
			\RWThumbs::create([
				'fullPath' => $fullPath,
				'imageUrl' => $inputUrl,
				'exifNumber' => $exif['number'],
				'quality' => 25,
				'overwrite' => false,
			]);
			
			$webPath = $dirs['web_gif_thumbnails'] . $fileName;
			$backgroundUrl = \RWHttp::getProtocol() . $_SERVER['SERVER_NAME'] . $webPath;
		}
		else {
			$type = 'image-raw';
			$backgroundUrl = $inputUrl;
		}
		
		$output = [
			'status' => 8,
			'type' => $type,
			'displayUrl' => $inputUrl,
			'size' => $size,
			'width' =>$width,
			'height' => $height,
			'dataUrl' => $inputUrl,
			'backgroundUrl' => $backgroundUrl,
		];
	}
	else {
		$output = [
			'status' => 7,
		];
	}
	
	return $output;
}

//Header content-type check of the file
function isImage($contentTypeString = '') {
	$contentTypeString=strtolower($contentTypeString);
		
	$validContentTypeArr  = [
		'image/png', 
		'image/jpg', 
		'image/jpeg', 
		'image/jpe',
		'image/gif',
		'image/tif',
		'image/tiff',
		'image/svg',
		'image/ico',
		'image/icon',
		'image/x-icon'
	];
	
	return in_array($contentTypeString, $validContentTypeArr);
}

//EXIF check of the file
function getExif($inputUrl) {
	$allowedTypes = [
		'1' => 'image/gif',
		'2' => 'image/jpeg',
		'3' => 'image/png',
		'6' => 'image/bmp',
		'17' => 'image/ico',
		'18' => 'image/webp',
	];
	
	set_error_handler(function ($err_severity, $err_msg, $err_file, $err_line, array $err_context) {
		throw new ErrorException( $err_msg, 0, $err_severity, $err_file, $err_line );
	}, E_WARNING);
	try {
		$exifNumber = exif_imagetype($inputUrl);
	} catch (Exception $e) {
		$exifNumber = -1;
	}
	restore_error_handler();
	
	$exifString = $allowedTypes[$exifNumber];
	
	return [
		'isImage' => isImage($exifString), 
		'string' => $exifString,
		'number' => $exifNumber,
	];
}

function getImageDimensions($inputUrl) {
	return getimagesize($inputUrl);
}

function isAnimated($inputUrl) {
	
	//an animated gif contains multiple "frames", with each frame having a
	//header made up of:
	// * a static 4-byte sequence (\x00\x21\xF9\x04)
	// * 4 variable bytes
	// * a static 2-byte sequence (\x00\x2C)
	$responseArr = \RWHttp::request([
		'url' => $inputUrl,
		'pattern' => '#\x00\x21\xF9\x04.{4}\x00[\x2C\x21]#s',
		'patternMatchCountLimit' => 2,
		'referer' => 'www.rewired.hu',
	]);
	
	//having at least two frames means its animated
	return $responseArr['patternMatchCount'] > 1;
}


?>