<?php namespace RWMedia\Api;

function routing() {
	
	$requestMethod = $_SERVER['REQUEST_METHOD'];
	$requestUri = $_SERVER['REQUEST_URI'];
	$dataString = $_SERVER['QUERY_STRING'];
	
	$idArr = [];
	$url = "";
	
	if ($requestMethod === 'GET') {
		//get ID or URL
		$response = \RWMedia\Crud::parseDataString($dataString);
		
		if (!$response['isEmpty']) {
			$idArr[] = $response['id'];
			$url = $response['isId'] ? "" : $dataString;
		}
	}
	else if ($requestMethod === 'POST') {
		$postRequestData = file_get_contents('php://input');
		
		//convert json data to an Array, and get ID array
		if (isset($postRequestData) && $postRequestData !== '') {
			$postRequestData = urldecode($postRequestData);
			$postRequest = json_decode($postRequestData, true);
			$dataArr = $postRequest['data'];
			
			foreach ($dataArr as $data) {
				$response = \RWMedia\Crud::parseDataString($data);
				
				if (!$response['isEmpty']) {
					$idArr[] = $response['id'];
					$url = $response['isId'] ? "" : $data; //program handles only single url over POST, for SET and SET_SYNC functions
				}
			}
		}
	}

	// Find out the type of this API request.
	// Valid types = get, get_group, log, log_group, set, set_sync, delete
	$apiRequestType = str_replace("?".$dataString, "", $requestUri);
	$pos = strrpos($apiRequestType, "/");
	$len = strlen($apiRequestType);
	$apiRequestType = strtolower(substr($apiRequestType, $pos+1, $len));
	
	// return drupal_json_output([
		// 'idArr' => $idArr,
		// 'id' => $id,
		// 'url' => $url,
	// ]);
	
	//route the request to corresponding functions
	if (count($idArr) > 0 && !in_array($apiRequestType, ['set', 'set_sync'])) {
		switch($apiRequestType) {
			case "get":
				$output = \RWMedia\Crud::get($idArr[0]);
				break;
			case "get_group":
				$output = \RWMedia\Crud::getGroup($idArr);
				break;
			case "log":			
				$output = \RWMedia\Crud::log($idArr[0]);
				break;
			case "log_group":
				$output = \RWMedia\Crud::logGroup($idArr);
				break;
			case "delete":
				$output = \RWMedia\Crud::delete($idArr[0]);
				break;
		}
	}
	else if ($url !== "") {
		switch($apiRequestType) {
			case "set":
				$output = \RWMedia\Crud::set($idArr[0], $url);
				break;
			case "set_sync":
				$output = \RWMedia\Crud::setSync($idArr[0], $url);
				break;
		}
	}
	//if data is empty, reply with API OK!
	else {
		$output = [
			'status-code' => '200',
			'status' => 'Rewired.hu Media API is OK.',
			'request-type' => $apiRequestType,
		];
	}
	
	//DEBUG
	// $output += [
		// 'postRequestData' => $postRequestData,
	// ];
	//END DEBUG
	
	drupal_json_output($output);
}

function steps() {

	try {
		$json = file_get_contents('php://input');
		// url = http://something.com
		// apiUrl = {site}/rwmedia/steps
		// id = url hashed
		// ttl = this input message TTL. If reaches 0, no more Steps calls will be made
		// maxTtl = message TTL will reset to this counter, after each successful Steps taken
		// nesting = tracks the times this Steps function was being requested for
		// waitForResponse = controls how each new Steps function is being requested. True=syncronised/blocking, False=async/non-blocking
		// log = contains the server message logs
		// appId = this application's credentials for self called HTML request
		
		$dataArr = json_decode($json, true);
		
		$dataArr['url'] = $dataArr['url'] ?? '';
		$dataArr['apiUrl'] = $dataArr['apiUrl'] ?? '';
		$dataArr['id'] = $dataArr['id'] ?? \RWMedia\Crypto::rwHash($url);
		$dataArr['ttl'] = --$dataArr['ttl'] ?? 0;
		$dataArr['maxTtl'] = $dataArr['maxTtl'] ?? 0;
		$dataArr['nesting'] = $dataArr['nesting'] ?? -1;
		$dataArr['nesting']++;
		$dataArr['waitForResponse'] = $dataArr['waitForResponse'] ?? 1;
		$dataArr['log'] = $dataArr['log'] ?? [];
		$dataArr['appId'] = $dataArr['appId'] ?? '';
		
		//answer to HTML GET request
		if ($_SERVER['REQUEST_METHOD'] === 'GET') {
			return drupal_json_output([
				'status-code' => '200',
				'status' => 'Rewired.hu Media API is OK.',
				'request-type' => 'steps',
			]);
		}
		
		$data = new \RWData($dataArr);
		
		$nestingLvl = $data->get('nesting');
		$data->log("STEPS API request: start (nesting lvl: $nestingLvl)");
		
		if ($nestingLvl < 1) { //dont repeat this after each nesting call	
			$data->log("ID = " . $data->get('id'));
		}
		
		$entryObj = \RWMedia\Database::getObj($data->get('id'));
		$status = $entryObj->status;
		
		switch($status) {
			case 404:
				$data->log('Status=404 (not found), Step 1 start (making new entry in DB)');
				\RWMedia\Steps::step1($data);
				break;
			case 1:
				$data->log('Status=1 (found), Step 2 start (verifying URL and connection)');
				\RWMedia\Steps::step2($data);
				break;
			case 2:
				$data->log('Status=2 (verified), Step 3 start (analyzing)');
				\RWMedia\Steps::step3($data, $entryObj);
				break;
			case 3:
				$data->log('Status=3 (processing or uploading), Step 4 start (check if processing or uploading is finished)');
				\RWMedia\Steps::step4($data, $entryObj);
				break;
			case 7:
				$data->log('Status=7 (finished, but not recognised).');
				break;
			case 8:
				$data->log('Status=8 (finished).');
				break;
			case 9:
				$data->log('Status=9 (failed)');
				break;
		}
		
		$data->log("STEPS API request: end (nesting lvl: $nestingLvl)");
		
	} catch (Exception $e) {
		$data->log("STEPS API request: error (nesting lvl: $nestingLvl)");
	}
	
	$output = json_encode($data->get());
	return drupal_json_output($output);	
}
	


?>