<?php namespace RWMedia;

class Crud {
	
	public static function get($id) {
		$output = self::log($id);
		
		self::formatGetOutput($output);
		
		return $output;    
	}

	public static function getGroup($idArr) {
		$outputArr = self::logGroup($idArr);
		
		foreach ($outputArr['data'] as &$output) {
			self::formatGetOutput($output);
		}
		
		return $outputArr;    
	}

	public static function log($id) {
		$entry = \RWMedia\Database::get($id);
		
		return self::formatLogEntry($entry);
	}

	public static function logGroup($idArr) {
		$entryArr = \RWMedia\Database::getGroup($idArr);
		
		$groupEntryArr = [];
		foreach ($entryArr as $key => $value) {
			$formattedLogEntry = self::formatLogEntry($value);
			
			$groupEntryArr[$key] = $formattedLogEntry;
		}
		
		$output = [
			'status-code' => '200',
			'data' => $groupEntryArr,
		];
		
		return $output;
	}

	public static function set($id, $url) {
		$url = urldecode($url);
		
		$apiServer = $_SERVER['SERVER_NAME']; // ip
		$apiPath = $GLOBALS['base_path'] . \RWMedia\settings()['dirs']['api_steps'];  // "/rewired/" + "rwmedia/steps"
		$apiUrl = $apiServer.$apiPath;
					
		$request = [
			'url' => $apiUrl,
			'data' => json_encode([
				'url' => $url,
				'apiUrl' => $apiUrl,
				'id' => $id,
				'ttl' => 3,
				'maxTtl' => 3,
				'waitForResponse' => 0,
				'appId' => \RWMedia\settings()['credentials']['rewired']['appId'],
			]),
			'requestType' => 'POST',
		];
		
		$response = \RWHttp::requestAsync($request);
		
		$output = [
			'status-code' => $response['headers']['status-code'],
			'status' => $response['data'],
		];
		
		return $output;
	}

	public static function setSync($id, $url) {
		$url = urldecode($url);
		
		$apiServer = $_SERVER['SERVER_NAME'];
		$apiPath = $GLOBALS['base_path'] . \RWMedia\settings()['dirs']['api_steps'];
		$apiUrl = $apiServer.$apiPath;
		
		$request = [
			'url' => $apiUrl,
			'data' => json_encode([
				'url' => $url,
				'apiUrl' => $apiUrl,
				'id' => $id,
				'ttl' => 3,
				'maxTtl' => 3,
				'waitForResponse' => 1,
				'appId' => \RWMedia\settings()['credentials']['rewired']['appId'],
			]),
			'requestType' => 'POST',
		];
		
		$responseArr = \RWHttp::request($request);
		
		if ($responseArr['headers']['status-code'] === '200') {
			$data = json_decode($responseArr['data'], true);
			$data = json_decode($data, true);
			
			$output = [
				'status-code' => $responseArr['headers']['status-code'],
				'status' => 'Entry set sent successfully.',
				'data' => $data,
			];
		}
		else {
			$output = [
				'status-code' => $responseArr['headers']['status-code'],
				'status' => 'Entry set error.',
				'response-headers' => $responseArr['headers'],
				'response-raw-data' => $responseArr['data'],
				'request-headers' => $responseArr['request'],
			];
		}
		
		return $output;
	}

	public static function delete($id) {
		$NumberOfRowsDeleted = \RWMedia\Database::delete($id);
		
		if ($NumberOfRowsDeleted > 0) {
			$output = [
				'status-code' => '200',
				'status' => 'Entry deleted successfully.',
			];
		}
		else {
			$output = [
				'status-code' => '404',
				'status' => 'Entry not found.',
			];
		}
		
		return $output;
	}
	
	public static function parseDataString($data) {
		$isId = false;
		$isEmpty = false;
		
		if (empty($data)) {
			$isEmpty = true;
		}
		//is data = ID? (sha256 hash = 44char long, in base64 encoding)
		else if (strlen($data) === 44 && \RWMedia\Crypto::decodeAndEncodeBase64($data) === $data) {
			$id = $data;
			$isId = true;
		}
		//data = URL presumably
		else if(strlen($data) > 0) {
			$id = \RWMedia\Crypto::rwHash($data);
		}
		
		return [
			'isId' => $isId,
			'id' => $id,
			'isEmpty' => $isEmpty,
		];
	}
	
	private static function formatGetOutput(&$output) {
		if ($output['status-code'] === '200') {
			//strip 'log' section
			unset($output['data']['log']);
			
			//strip 'created' section
			unset($output['data']['created']);
			
			//strip null data elements
			$output['data'] = array_filter($output['data'], function($value) {
				return !is_null($value);
			});
		}
		
		//strip status (message)
		unset($output['status']);
	}

	private static function formatLogEntry($entry) {
		if ($entry && $entry['status'] !== '404') {
			$output = [
				'status-code' => '200',
				'status' => 'Entry found.',
				'data' => [
					'status' => $entry['status'] ?? "",
					'id' => $entry['id'] ?? "",
					'display_url' => $entry['display_url'] ?? "",
					'created' => $entry['created'] ?? "",
					
					'type' => $entry['type'],
					'data_url' => $entry['data_url'],
					
					'webm_url' => $entry['webm_url'],
					'mp4_url' => $entry['mp4_url'],
					
					'title' => $entry['title'],
					'video_duration' => $entry['video_duration'],
					'upload_percentage' => $entry['upload_percentage'],
					'background_url' => $entry['background_url'],
					'size' => $entry['size'],
					'width' => $entry['width'],
					'height' => $entry['height'],
					
					'log' => !is_null($entry['log']) ? json_decode($entry['log'], true) : "",
				], 
			];
		}
		else {
			$output = [
				'status-code' => '404',
				'status' => 'Entry not found.',
			];
		}
		
		return $output;
	}
	
	
}


?>