<?php namespace RWMedia;

class Database {
	
	//GET
	public static function get($id) {
		$query = db_query(
			'SELECT * FROM {rwmedia} where id = :id', 
			[':id' => $id]
		);

		$record = $query->fetch();
			
		if (!$record) {
			$record = [
				'status' => '404',
			];
		}
		
		return (array)$record;
	}

	public static function getObj($id) {
		return json_decode(json_encode(self::get($id)));
	}

	//GET GROUP
	public static function getGroup($idArr) {
		$outputArr = [];
			
		$query = db_query(
			'SELECT * FROM {rwmedia} WHERE id IN (:idArr)', 
			[':idArr' => $idArr]
		);
		
		$recordArr = $query->fetchAll();
		
		//make an array of not found IDs
		$foundIdArr = [];
		foreach ($recordArr as $record) {
			$foundIdArr[] = $record->id;
		}
		
		//handle not found records
		$notFoundIdArr = array_diff($idArr, $foundIdArr);
		$notFoundRecordArr = [];
		foreach ($notFoundIdArr as $notFoundId) {
			$record = [
				'status' => '404',
			];
			
			$notFoundRecordArr[$notFoundId] = $record;
		}
		
		//convert found records to Associative Arrays
		foreach ($recordArr as $record) {
			$outputArr[$record->id] = (array)$record;
		}
		
		//combine found and not found records
		$outputArr += $notFoundRecordArr;
		
		return $outputArr;
	}

	//DELETE
	public static function delete($id) {
		return db_delete('rwmedia')
		  ->condition('id', $id)
		  ->execute();
	}

	//INSERT + UPDATE = MERGE
	public static function insert($args, $tableName) {
		
		return db_merge($tableName)
			->key(['id' => $args['id']])
			->fields($args)
			->execute();
	}

}

?>